==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPRouteContainer.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPRouteContainer_cxx_Version = 
"$Id: TRIPRouteContainer.cxx,v 1.2 2000/11/08 22:58:01 surendra Exp $";

#include "TRIPRouteContainer.hxx"
#include "cpLog.h"


TRIPRouteContainer::TRIPRouteContainer(const TRIPRouteContainer& other) 
{
     copyObj(other);
}

TRIPRouteContainer& 
TRIPRouteContainer::operator=(const TRIPRouteContainer& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

TRIPRouteContainer& 
TRIPRouteContainer::operator<<(const TRIPRoutes& data)
{
    addRoute(data);
    return *this;
}

void
TRIPRouteContainer::addRoute(const TRIPRoutes& data)
{
    _routeList.push_back(data);
    _len += data.getLength();
    setLength(_len);
}

void 
TRIPRouteContainer::dump(ostream& os) const
{
    RouteList::const_iterator itr;
    for(itr = _routeList.begin(); 
              itr != _routeList.end(); itr++)
    {
         const TRIPRoutes& data = (*itr);
         os << data << endl;
    }
}

void 
TRIPRouteContainer::writeData(int id) const throw(VNetworkException&)
{
    TRIPRouteAttr::writeData(id);
    RouteList::const_iterator itr;
    for(itr = _routeList.begin(); 
              itr != _routeList.end(); itr++)
    {
         const TRIPRoutes& data = (*itr);
         data.writeData(id);
    }
}

TRIPRouteContainer::TRIPRouteContainer(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPRouteAttr(buf)
{
    int hdrLen  = _hdr->getHdrLength(); 
    int len  = _hdr->getLength(); 

    _len = 0;
    parseRoutes(buf+hdrLen, len);
}

void
TRIPRouteContainer::parseRoutes(const char* buf, u_int16_t len)
{
    u_int16_t tLen = 0;
    while(tLen < len)
    {
        TRIPRoutes tsData(buf+tLen);                
        tLen += tsData.getLength();
        addRoute(tsData);
    }
}

void 
TRIPRouteContainer::copyObj(const TRIPRouteContainer& other)
{
    TRIPRouteAttr::copyObj(other);
    _routeList.clear();
    _len = 0;
    RouteList::const_iterator itr;
    for(itr = other._routeList.begin(); 
              itr != other._routeList.end(); itr++)
    {
         const TRIPRoutes& data = (*itr);
         addRoute(data);
    }
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPRouteContainer.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPRouteContainer_cxx_Version = 
"$Id: TRIPRouteContainer.cxx,v 1.7 2001/01/20 02:35:18 sprajpat Exp $";

#include "TRIPRouteContainer.hxx"
#include "cpLog.h"


TRIPRouteContainer::TRIPRouteContainer(const TRIPRouteContainer& other) 
{
     copyObj(other);
}

TRIPRouteContainer& 
TRIPRouteContainer::operator=(const TRIPRouteContainer& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

TRIPRouteContainer& 
TRIPRouteContainer::operator<<(const TRIPRoutes& data)
{
    addRoute(data);
    return *this;
}

void
TRIPRouteContainer::addRoute(const TRIPRoutes& data)
{
    _routeList.push_back(data);
    _len += data.getLength();
    ///Since length is 16 bit number, the max it can hold is 65535 size.
    //In reality there should not be these many routes in a single Update
    //Message
    assert(_len < 65535);
    setLength(_len);
}

void 
TRIPRouteContainer::dump(ostream& os) const
{
    for(RouteList::const_iterator itr = _routeList.begin(); 
              itr != _routeList.end(); itr++)
    {
         os << (*itr) << endl;
    }
}

void 
TRIPRouteContainer::writeData(int id) const throw(VNetworkException&)
{
    TRIPRouteAttr::writeData(id);
    for(RouteList::const_iterator  itr = _routeList.begin(); 
              itr != _routeList.end(); itr++)
    {
         (*itr).writeData(id);
    }
}

TRIPRouteContainer::TRIPRouteContainer(const char* buf) 
        throw (TRIPBadDataException&)
    : TRIPRouteAttr(buf)
{
    int hdrLen  = _hdr->getHdrLength(); 
    int len  = _hdr->getLength(); 

    _len = 0;
    parseRoutes(buf+hdrLen, len);
}

void
TRIPRouteContainer::parseRoutes(const char* buf, u_int16_t len)
{
    u_int16_t tLen = 0;
    while(tLen < len)
    {
        TRIPRoutes tsData(buf+tLen);                
        tLen += tsData.getLength();
        addRoute(tsData);
    }
}

void 
TRIPRouteContainer::copyObj(const TRIPRouteContainer& other)
{
    TRIPRouteAttr::copyObj(other);
    _routeList.clear();
    _len = 0;
    for(RouteList::const_iterator itr = other._routeList.begin(); 
              itr != other._routeList.end(); itr++)
    {
         const TRIPRoutes& data = (*itr);
         addRoute(data);
    }
}
